<!-- ---
!-- Timestamp: 2025-12-25 07:04:17
!-- Author: ywatanabe
!-- File: /home/ywatanabe/proj/figrecipe/KNOWN_ISSUES.md
!-- --- -->

## Partial color change
- [ ] Not working for some methods like ax.bar()
- [ ] Breaks layout (e.g., in pie chart)
- [ ] Does not change color (e.g., in pie chart)

<!-- EOF -->